@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 3.7.6.  */
+/* A Bison parser, made by GNU Bison 3.8.2.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
@@ -46,10 +46,10 @@
    USER NAME SPACE" below.  */
 
 /* Identify Bison output, and Bison version.  */
-#define YYBISON 30706
+#define YYBISON 30802
 
 /* Bison version string.  */
-#define YYBISON_VERSION "3.7.6"
+#define YYBISON_VERSION "3.8.2"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -230,9 +230,11 @@ typedef union YYSTYPE YYSTYPE;
 
 extern YYSTYPE yylval;
 
+
 int yyparse (void);
 
 
+
 /* Symbol kind.  */
 enum yysymbol_kind_t
 {
@@ -442,12 +444,18 @@ typedef int yy_state_fast_t;
 # define YY_USE(E) /* empty */
 #endif
 
-#if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
 /* Suppress an incorrect diagnostic about yylval being uninitialized.  */
-# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                            \
+#if defined __GNUC__ && ! defined __ICC && 406 <= __GNUC__ * 100 + __GNUC_MINOR__
+# if __GNUC__ * 100 + __GNUC_MINOR__ < 407
+#  define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                           \
+    _Pragma ("GCC diagnostic push")                                     \
+    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")
+# else
+#  define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                           \
     _Pragma ("GCC diagnostic push")                                     \
     _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")              \
     _Pragma ("GCC diagnostic ignored \"-Wmaybe-uninitialized\"")
+# endif
 # define YY_IGNORE_MAYBE_UNINITIALIZED_END      \
     _Pragma ("GCC diagnostic pop")
 #else
@@ -662,7 +670,7 @@ static const yytype_int8 yytranslate[] =
 };
 
 #if YYDEBUG
-  /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
+/* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_int16 yyrline[] =
 {
        0,   120,   120,   121,   125,   134,   135,   142,   147,   152,
@@ -705,17 +713,6 @@ yysymbol_name (yysymbol_kind_t yysymbol)
 }
 #endif
 
-#ifdef YYPRINT
-/* YYTOKNUM[NUM] -- (External) token number corresponding to the
-   (internal) symbol number NUM (which must be that of a token).  */
-static const yytype_int16 yytoknum[] =
-{
-       0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
-     265,   266,   267,   268,    38,    60,    62,    35,    40,    41,
-      43,    45,    44,    91,    93,    64,    47
-};
-#endif
-
 #define YYPACT_NINF (-98)
 
 #define yypact_value_is_default(Yyn) \
@@ -726,8 +723,8 @@ static const yytype_int16 yytoknum[] =
 #define yytable_value_is_error(Yyn) \
   0
 
-  /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
-     STATE-NUM.  */
+/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
+   STATE-NUM.  */
 static const yytype_int16 yypact[] =
 {
       89,    14,     9,    31,    35,   -98,   -98,   -98,   -98,     0,
@@ -750,9 +747,9 @@ static const yytype_int16 yypact[] =
      191,   192,   -98,   -98,   193,   194,   -98,   -98,   -98,   -98
 };
 
-  /* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
-     Performed when YYTABLE does not specify something else to do.  Zero
-     means the default is an error.  */
+/* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
+   Performed when YYTABLE does not specify something else to do.  Zero
+   means the default is an error.  */
 static const yytype_int8 yydefact[] =
 {
       68,    86,    87,    88,    89,    64,    67,    66,    13,    14,
@@ -775,7 +772,7 @@ static const yytype_int8 yydefact[] =
        0,     0,    37,    52,     0,     0,    41,    43,    51,    53
 };
 
-  /* YYPGOTO[NTERM-NUM].  */
+/* YYPGOTO[NTERM-NUM].  */
 static const yytype_int16 yypgoto[] =
 {
      -98,   -98,   196,   -98,   -98,   -98,   -81,     6,   -98,    -9,
@@ -783,7 +780,7 @@ static const yytype_int16 yypgoto[] =
       12
 };
 
-  /* YYDEFGOTO[NTERM-NUM].  */
+/* YYDEFGOTO[NTERM-NUM].  */
 static const yytype_int8 yydefgoto[] =
 {
        0,    16,    46,    17,    18,    19,   100,    40,   101,   102,
@@ -791,9 +788,9 @@ static const yytype_int8 yydefgoto[] =
       76
 };
 
-  /* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
-     positive, shift that token.  If negative, reduce the rule whose
-     number is the opposite.  If YYTABLE_NINF, syntax error.  */
+/* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
+   positive, shift that token.  If negative, reduce the rule whose
+   number is the opposite.  If YYTABLE_NINF, syntax error.  */
 static const yytype_int16 yytable[] =
 {
      106,   110,    21,    78,   111,    41,    50,   117,    50,   -10,
@@ -846,8 +843,8 @@ static const yytype_int16 yycheck[] =
       19,    19,    19,    19,    -1,    19
 };
 
-  /* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
-     symbol of state STATE-NUM.  */
+/* YYSTOS[STATE-NUM] -- The symbol kind of the accessing symbol of
+   state STATE-NUM.  */
 static const yytype_int8 yystos[] =
 {
        0,     3,     4,     5,     6,     7,     8,    10,    11,    13,
@@ -870,7 +867,7 @@ static const yytype_int8 yystos[] =
       42,    42,    19,    19,    33,    13,    19,    19,    19,    19
 };
 
-  /* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
+/* YYR1[RULE-NUM] -- Symbol kind of the left-hand side of rule RULE-NUM.  */
 static const yytype_int8 yyr1[] =
 {
        0,    27,    28,    28,    28,    29,    29,    30,    30,    30,
@@ -884,7 +881,7 @@ static const yytype_int8 yyr1[] =
       44,    45,    45,    45,    45,    46,    47,    47,    47,    47
 };
 
-  /* YYR2[YYN] -- Number of symbols on the right hand side of rule YYN.  */
+/* YYR2[RULE-NUM] -- Number of symbols on the right-hand side of rule RULE-NUM.  */
 static const yytype_int8 yyr2[] =
 {
        0,     2,     1,     2,     2,     0,     1,     2,     2,     1,
@@ -907,6 +904,7 @@ enum { YYENOMEM = -2 };
 #define YYACCEPT        goto yyacceptlab
 #define YYABORT         goto yyabortlab
 #define YYERROR         goto yyerrorlab
+#define YYNOMEM         goto yyexhaustedlab
 
 
 #define YYRECOVERING()  (!!yyerrstatus)
@@ -947,10 +945,7 @@ do {                                            \
     YYFPRINTF Args;                             \
 } while (0)
 
-/* This macro is provided for backward compatibility. */
-# ifndef YY_LOCATION_PRINT
-#  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
-# endif
+
 
 
 # define YY_SYMBOL_PRINT(Title, Kind, Value, Location)                    \
@@ -977,10 +972,6 @@ yy_symbol_value_print (FILE *yyo,
   YY_USE (yyoutput);
   if (!yyvaluep)
     return;
-# ifdef YYPRINT
-  if (yykind < YYNTOKENS)
-    YYPRINT (yyo, yytoknum[yykind], *yyvaluep);
-# endif
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   YY_USE (yykind);
   YY_IGNORE_MAYBE_UNINITIALIZED_END
@@ -1165,6 +1156,7 @@ yyparse (void)
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yychar = YYEMPTY; /* Cause a token to be read.  */
+
   goto yysetstate;
 
 
@@ -1190,7 +1182,7 @@ yysetstate:
 
   if (yyss + yystacksize - 1 <= yyssp)
 #if !defined yyoverflow && !defined YYSTACK_RELOCATE
-    goto yyexhaustedlab;
+    YYNOMEM;
 #else
     {
       /* Get the current used size of the three stacks, in elements.  */
@@ -1218,7 +1210,7 @@ yysetstate:
 # else /* defined YYSTACK_RELOCATE */
       /* Extend the stack our own way.  */
       if (YYMAXDEPTH <= yystacksize)
-        goto yyexhaustedlab;
+        YYNOMEM;
       yystacksize *= 2;
       if (YYMAXDEPTH < yystacksize)
         yystacksize = YYMAXDEPTH;
@@ -1229,7 +1221,7 @@ yysetstate:
           YY_CAST (union yyalloc *,
                    YYSTACK_ALLOC (YY_CAST (YYSIZE_T, YYSTACK_BYTES (yystacksize))));
         if (! yyptr)
-          goto yyexhaustedlab;
+          YYNOMEM;
         YYSTACK_RELOCATE (yyss_alloc, yyss);
         YYSTACK_RELOCATE (yyvs_alloc, yyvs);
 #  undef YYSTACK_RELOCATE
@@ -1251,6 +1243,7 @@ yysetstate:
     }
 #endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */
 
+
   if (yystate == YYFINAL)
     YYACCEPT;
 
@@ -1367,7 +1360,7 @@ yyreduce:
                 {
 		  op->trailing_ampersand = (yyvsp[0].trailing_ampersand);
 		}
-#line 1371 "config/m68k-parse.c"
+#line 1364 "config/m68k-parse.c"
     break;
 
   case 4: /* operand: mit_operand optional_ampersand  */
@@ -1375,19 +1368,19 @@ yyreduce:
                 {
 		  op->trailing_ampersand = (yyvsp[0].trailing_ampersand);
 		}
-#line 1379 "config/m68k-parse.c"
+#line 1372 "config/m68k-parse.c"
     break;
 
   case 5: /* optional_ampersand: %empty  */
 #line 134 "./config/m68k-parse.y"
                 { (yyval.trailing_ampersand) = 0; }
-#line 1385 "config/m68k-parse.c"
+#line 1378 "config/m68k-parse.c"
     break;
 
   case 6: /* optional_ampersand: '&'  */
 #line 136 "./config/m68k-parse.y"
                 { (yyval.trailing_ampersand) = 1; }
-#line 1391 "config/m68k-parse.c"
+#line 1384 "config/m68k-parse.c"
     break;
 
   case 7: /* generic_operand: '<' '<'  */
@@ -1395,7 +1388,7 @@ yyreduce:
                 {
 		  op->mode = LSH;
 		}
-#line 1399 "config/m68k-parse.c"
+#line 1392 "config/m68k-parse.c"
     break;
 
   case 8: /* generic_operand: '>' '>'  */
@@ -1403,7 +1396,7 @@ yyreduce:
                 {
 		  op->mode = RSH;
 		}
-#line 1407 "config/m68k-parse.c"
+#line 1400 "config/m68k-parse.c"
     break;
 
   case 9: /* generic_operand: DR  */
@@ -1412,7 +1405,7 @@ yyreduce:
 		  op->mode = DREG;
 		  op->reg = (yyvsp[0].reg);
 		}
-#line 1416 "config/m68k-parse.c"
+#line 1409 "config/m68k-parse.c"
     break;
 
   case 10: /* generic_operand: AR  */
@@ -1421,7 +1414,7 @@ yyreduce:
 		  op->mode = AREG;
 		  op->reg = (yyvsp[0].reg);
 		}
-#line 1425 "config/m68k-parse.c"
+#line 1418 "config/m68k-parse.c"
     break;
 
   case 11: /* generic_operand: FPR  */
@@ -1430,7 +1423,7 @@ yyreduce:
 		  op->mode = FPREG;
 		  op->reg = (yyvsp[0].reg);
 		}
-#line 1434 "config/m68k-parse.c"
+#line 1427 "config/m68k-parse.c"
     break;
 
   case 12: /* generic_operand: FPCR  */
@@ -1439,7 +1432,7 @@ yyreduce:
 		  op->mode = CONTROL;
 		  op->reg = (yyvsp[0].reg);
 		}
-#line 1443 "config/m68k-parse.c"
+#line 1436 "config/m68k-parse.c"
     break;
 
   case 13: /* generic_operand: CREG  */
@@ -1448,7 +1441,7 @@ yyreduce:
 		  op->mode = CONTROL;
 		  op->reg = (yyvsp[0].reg);
 		}
-#line 1452 "config/m68k-parse.c"
+#line 1445 "config/m68k-parse.c"
     break;
 
   case 14: /* generic_operand: EXPR  */
@@ -1457,7 +1450,7 @@ yyreduce:
 		  op->mode = ABSL;
 		  op->disp = (yyvsp[0].exp);
 		}
-#line 1461 "config/m68k-parse.c"
+#line 1454 "config/m68k-parse.c"
     break;
 
   case 15: /* generic_operand: '#' EXPR  */
@@ -1466,7 +1459,7 @@ yyreduce:
 		  op->mode = IMMED;
 		  op->disp = (yyvsp[0].exp);
 		}
-#line 1470 "config/m68k-parse.c"
+#line 1463 "config/m68k-parse.c"
     break;
 
   case 16: /* generic_operand: '&' EXPR  */
@@ -1475,7 +1468,7 @@ yyreduce:
 		  op->mode = IMMED;
 		  op->disp = (yyvsp[0].exp);
 		}
-#line 1479 "config/m68k-parse.c"
+#line 1472 "config/m68k-parse.c"
     break;
 
   case 17: /* generic_operand: reglist  */
@@ -1484,7 +1477,7 @@ yyreduce:
 		  op->mode = REGLST;
 		  op->mask = (yyvsp[0].mask);
 		}
-#line 1488 "config/m68k-parse.c"
+#line 1481 "config/m68k-parse.c"
     break;
 
   case 18: /* motorola_operand: '(' AR ')'  */
@@ -1493,7 +1486,7 @@ yyreduce:
 		  op->mode = AINDR;
 		  op->reg = (yyvsp[-1].reg);
 		}
-#line 1497 "config/m68k-parse.c"
+#line 1490 "config/m68k-parse.c"
     break;
 
   case 19: /* motorola_operand: '(' AR ')' '+'  */
@@ -1502,7 +1495,7 @@ yyreduce:
 		  op->mode = AINC;
 		  op->reg = (yyvsp[-2].reg);
 		}
-#line 1506 "config/m68k-parse.c"
+#line 1499 "config/m68k-parse.c"
     break;
 
   case 20: /* motorola_operand: '-' '(' AR ')'  */
@@ -1511,7 +1504,7 @@ yyreduce:
 		  op->mode = ADEC;
 		  op->reg = (yyvsp[-1].reg);
 		}
-#line 1515 "config/m68k-parse.c"
+#line 1508 "config/m68k-parse.c"
     break;
 
   case 21: /* motorola_operand: '(' EXPR ',' zapc ')'  */
@@ -1525,7 +1518,7 @@ yyreduce:
 		  else
 		    op->mode = DISP;
 		}
-#line 1529 "config/m68k-parse.c"
+#line 1522 "config/m68k-parse.c"
     break;
 
   case 22: /* motorola_operand: '(' zapc ',' EXPR ')'  */
@@ -1539,7 +1532,7 @@ yyreduce:
 		  else
 		    op->mode = DISP;
 		}
-#line 1543 "config/m68k-parse.c"
+#line 1536 "config/m68k-parse.c"
     break;
 
   case 23: /* motorola_operand: EXPR '(' zapc ')'  */
@@ -1553,7 +1546,7 @@ yyreduce:
 		  else
 		    op->mode = DISP;
 		}
-#line 1557 "config/m68k-parse.c"
+#line 1550 "config/m68k-parse.c"
     break;
 
   case 24: /* motorola_operand: '(' LPC ')'  */
@@ -1562,7 +1555,7 @@ yyreduce:
 		  op->mode = DISP;
 		  op->reg = (yyvsp[-1].reg);
 		}
-#line 1566 "config/m68k-parse.c"
+#line 1559 "config/m68k-parse.c"
     break;
 
   case 25: /* motorola_operand: '(' ZAR ')'  */
@@ -1571,7 +1564,7 @@ yyreduce:
 		  op->mode = BASE;
 		  op->reg = (yyvsp[-1].reg);
 		}
-#line 1575 "config/m68k-parse.c"
+#line 1568 "config/m68k-parse.c"
     break;
 
   case 26: /* motorola_operand: '(' LZPC ')'  */
@@ -1580,7 +1573,7 @@ yyreduce:
 		  op->mode = BASE;
 		  op->reg = (yyvsp[-1].reg);
 		}
-#line 1584 "config/m68k-parse.c"
+#line 1577 "config/m68k-parse.c"
     break;
 
   case 27: /* motorola_operand: '(' EXPR ',' zapc ',' zireg ')'  */
@@ -1591,7 +1584,7 @@ yyreduce:
 		  op->disp = (yyvsp[-5].exp);
 		  op->index = (yyvsp[-1].indexreg);
 		}
-#line 1595 "config/m68k-parse.c"
+#line 1588 "config/m68k-parse.c"
     break;
 
   case 28: /* motorola_operand: '(' EXPR ',' zapc ',' zpc ')'  */
@@ -1606,7 +1599,7 @@ yyreduce:
 		  op->index.size = SIZE_UNSPEC;
 		  op->index.scale = 1;
 		}
-#line 1610 "config/m68k-parse.c"
+#line 1603 "config/m68k-parse.c"
     break;
 
   case 29: /* motorola_operand: '(' EXPR ',' zdireg optczapc ')'  */
@@ -1617,7 +1610,7 @@ yyreduce:
 		  op->disp = (yyvsp[-4].exp);
 		  op->index = (yyvsp[-2].indexreg);
 		}
-#line 1621 "config/m68k-parse.c"
+#line 1614 "config/m68k-parse.c"
     break;
 
   case 30: /* motorola_operand: '(' zdireg ',' EXPR ')'  */
@@ -1627,7 +1620,7 @@ yyreduce:
 		  op->disp = (yyvsp[-1].exp);
 		  op->index = (yyvsp[-3].indexreg);
 		}
-#line 1631 "config/m68k-parse.c"
+#line 1624 "config/m68k-parse.c"
     break;
 
   case 31: /* motorola_operand: EXPR '(' zapc ',' zireg ')'  */
@@ -1638,7 +1631,7 @@ yyreduce:
 		  op->disp = (yyvsp[-5].exp);
 		  op->index = (yyvsp[-1].indexreg);
 		}
-#line 1642 "config/m68k-parse.c"
+#line 1635 "config/m68k-parse.c"
     break;
 
   case 32: /* motorola_operand: '(' zapc ',' zireg ')'  */
@@ -1648,7 +1641,7 @@ yyreduce:
 		  op->reg = (yyvsp[-3].reg);
 		  op->index = (yyvsp[-1].indexreg);
 		}
-#line 1652 "config/m68k-parse.c"
+#line 1645 "config/m68k-parse.c"
     break;
 
   case 33: /* motorola_operand: EXPR '(' zapc ',' zpc ')'  */
@@ -1663,7 +1656,7 @@ yyreduce:
 		  op->index.size = SIZE_UNSPEC;
 		  op->index.scale = 1;
 		}
-#line 1667 "config/m68k-parse.c"
+#line 1660 "config/m68k-parse.c"
     break;
 
   case 34: /* motorola_operand: '(' zapc ',' zpc ')'  */
@@ -1677,7 +1670,7 @@ yyreduce:
 		  op->index.size = SIZE_UNSPEC;
 		  op->index.scale = 1;
 		}
-#line 1681 "config/m68k-parse.c"
+#line 1674 "config/m68k-parse.c"
     break;
 
   case 35: /* motorola_operand: EXPR '(' zdireg optczapc ')'  */
@@ -1688,7 +1681,7 @@ yyreduce:
 		  op->disp = (yyvsp[-4].exp);
 		  op->index = (yyvsp[-2].indexreg);
 		}
-#line 1692 "config/m68k-parse.c"
+#line 1685 "config/m68k-parse.c"
     break;
 
   case 36: /* motorola_operand: '(' zdireg optczapc ')'  */
@@ -1698,7 +1691,7 @@ yyreduce:
 		  op->reg = (yyvsp[-1].reg);
 		  op->index = (yyvsp[-2].indexreg);
 		}
-#line 1702 "config/m68k-parse.c"
+#line 1695 "config/m68k-parse.c"
     break;
 
   case 37: /* motorola_operand: '(' '[' EXPR optczapc ']' ',' zireg optcexpr ')'  */
@@ -1710,7 +1703,7 @@ yyreduce:
 		  op->index = (yyvsp[-2].indexreg);
 		  op->odisp = (yyvsp[-1].exp);
 		}
-#line 1714 "config/m68k-parse.c"
+#line 1707 "config/m68k-parse.c"
     break;
 
   case 38: /* motorola_operand: '(' '[' EXPR optczapc ']' optcexpr ')'  */
@@ -1721,7 +1714,7 @@ yyreduce:
 		  op->disp = (yyvsp[-4].exp);
 		  op->odisp = (yyvsp[-1].exp);
 		}
-#line 1725 "config/m68k-parse.c"
+#line 1718 "config/m68k-parse.c"
     break;
 
   case 39: /* motorola_operand: '(' '[' zapc ']' ',' zireg optcexpr ')'  */
@@ -1732,7 +1725,7 @@ yyreduce:
 		  op->index = (yyvsp[-2].indexreg);
 		  op->odisp = (yyvsp[-1].exp);
 		}
-#line 1736 "config/m68k-parse.c"
+#line 1729 "config/m68k-parse.c"
     break;
 
   case 40: /* motorola_operand: '(' '[' zapc ']' optcexpr ')'  */
@@ -1742,7 +1735,7 @@ yyreduce:
 		  op->reg = (yyvsp[-3].reg);
 		  op->odisp = (yyvsp[-1].exp);
 		}
-#line 1746 "config/m68k-parse.c"
+#line 1739 "config/m68k-parse.c"
     break;
 
   case 41: /* motorola_operand: '(' '[' EXPR ',' zapc ',' zireg ']' optcexpr ')'  */
@@ -1754,7 +1747,7 @@ yyreduce:
 		  op->index = (yyvsp[-3].indexreg);
 		  op->odisp = (yyvsp[-1].exp);
 		}
-#line 1758 "config/m68k-parse.c"
+#line 1751 "config/m68k-parse.c"
     break;
 
   case 42: /* motorola_operand: '(' '[' zapc ',' zireg ']' optcexpr ')'  */
@@ -1765,7 +1758,7 @@ yyreduce:
 		  op->index = (yyvsp[-3].indexreg);
 		  op->odisp = (yyvsp[-1].exp);
 		}
-#line 1769 "config/m68k-parse.c"
+#line 1762 "config/m68k-parse.c"
     break;
 
   case 43: /* motorola_operand: '(' '[' EXPR ',' zapc ',' zpc ']' optcexpr ')'  */
@@ -1781,7 +1774,7 @@ yyreduce:
 		  op->index.scale = 1;
 		  op->odisp = (yyvsp[-1].exp);
 		}
-#line 1785 "config/m68k-parse.c"
+#line 1778 "config/m68k-parse.c"
     break;
 
   case 44: /* motorola_operand: '(' '[' zapc ',' zpc ']' optcexpr ')'  */
@@ -1796,7 +1789,7 @@ yyreduce:
 		  op->index.scale = 1;
 		  op->odisp = (yyvsp[-1].exp);
 		}
-#line 1800 "config/m68k-parse.c"
+#line 1793 "config/m68k-parse.c"
     break;
 
   case 45: /* motorola_operand: '(' '[' optexprc zdireg optczapc ']' optcexpr ')'  */
@@ -1808,7 +1801,7 @@ yyreduce:
 		  op->index = (yyvsp[-4].indexreg);
 		  op->odisp = (yyvsp[-1].exp);
 		}
-#line 1812 "config/m68k-parse.c"
+#line 1805 "config/m68k-parse.c"
     break;
 
   case 46: /* mit_operand: optzapc '@'  */
@@ -1820,7 +1813,7 @@ yyreduce:
 		  op->mode = AINDR;
 		  op->reg = (yyvsp[-1].reg);
 		}
-#line 1824 "config/m68k-parse.c"
+#line 1817 "config/m68k-parse.c"
     break;
 
   case 47: /* mit_operand: optzapc '@' '+'  */
@@ -1832,7 +1825,7 @@ yyreduce:
 		  op->mode = AINC;
 		  op->reg = (yyvsp[-2].reg);
 		}
-#line 1836 "config/m68k-parse.c"
+#line 1829 "config/m68k-parse.c"
     break;
 
   case 48: /* mit_operand: optzapc '@' '-'  */
@@ -1844,7 +1837,7 @@ yyreduce:
 		  op->mode = ADEC;
 		  op->reg = (yyvsp[-2].reg);
 		}
-#line 1848 "config/m68k-parse.c"
+#line 1841 "config/m68k-parse.c"
     break;
 
   case 49: /* mit_operand: optzapc '@' '(' EXPR ')'  */
@@ -1858,7 +1851,7 @@ yyreduce:
 		  else
 		    op->mode = DISP;
 		}
-#line 1862 "config/m68k-parse.c"
+#line 1855 "config/m68k-parse.c"
     break;
 
   case 50: /* mit_operand: optzapc '@' '(' optexprc zireg ')'  */
@@ -1869,7 +1862,7 @@ yyreduce:
 		  op->disp = (yyvsp[-2].exp);
 		  op->index = (yyvsp[-1].indexreg);
 		}
-#line 1873 "config/m68k-parse.c"
+#line 1866 "config/m68k-parse.c"
     break;
 
   case 51: /* mit_operand: optzapc '@' '(' EXPR ')' '@' '(' optexprc zireg ')'  */
@@ -1881,7 +1874,7 @@ yyreduce:
 		  op->index = (yyvsp[-1].indexreg);
 		  op->odisp = (yyvsp[-2].exp);
 		}
-#line 1885 "config/m68k-parse.c"
+#line 1878 "config/m68k-parse.c"
     break;
 
   case 52: /* mit_operand: optzapc '@' '(' EXPR ')' '@' '(' EXPR ')'  */
@@ -1892,7 +1885,7 @@ yyreduce:
 		  op->disp = (yyvsp[-5].exp);
 		  op->odisp = (yyvsp[-1].exp);
 		}
-#line 1896 "config/m68k-parse.c"
+#line 1889 "config/m68k-parse.c"
     break;
 
   case 53: /* mit_operand: optzapc '@' '(' optexprc zireg ')' '@' '(' EXPR ')'  */
@@ -1904,7 +1897,7 @@ yyreduce:
 		  op->index = (yyvsp[-5].indexreg);
 		  op->odisp = (yyvsp[-1].exp);
 		}
-#line 1908 "config/m68k-parse.c"
+#line 1901 "config/m68k-parse.c"
     break;
 
   case 55: /* zireg: zadr  */
@@ -1914,7 +1907,7 @@ yyreduce:
 		  (yyval.indexreg).size = SIZE_UNSPEC;
 		  (yyval.indexreg).scale = 1;
 		}
-#line 1918 "config/m68k-parse.c"
+#line 1911 "config/m68k-parse.c"
     break;
 
   case 57: /* zdireg: zdr  */
@@ -1924,7 +1917,7 @@ yyreduce:
 		  (yyval.indexreg).size = SIZE_UNSPEC;
 		  (yyval.indexreg).scale = 1;
 		}
-#line 1928 "config/m68k-parse.c"
+#line 1921 "config/m68k-parse.c"
     break;
 
   case 68: /* optzapc: %empty  */
@@ -1932,7 +1925,7 @@ yyreduce:
                 {
 		  (yyval.reg) = ZADDR0;
 		}
-#line 1936 "config/m68k-parse.c"
+#line 1929 "config/m68k-parse.c"
     break;
 
   case 72: /* optczapc: %empty  */
@@ -1940,7 +1933,7 @@ yyreduce:
                 {
 		  (yyval.reg) = ZADDR0;
 		}
-#line 1944 "config/m68k-parse.c"
+#line 1937 "config/m68k-parse.c"
     break;
 
   case 73: /* optczapc: ',' zapc  */
@@ -1948,7 +1941,7 @@ yyreduce:
                 {
 		  (yyval.reg) = (yyvsp[0].reg);
 		}
-#line 1952 "config/m68k-parse.c"
+#line 1945 "config/m68k-parse.c"
     break;
 
   case 74: /* optcexpr: %empty  */
@@ -1957,7 +1950,7 @@ yyreduce:
 		  (yyval.exp).exp.X_op = O_absent;
 		  (yyval.exp).size = SIZE_UNSPEC;
 		}
-#line 1961 "config/m68k-parse.c"
+#line 1954 "config/m68k-parse.c"
     break;
 
   case 75: /* optcexpr: ',' EXPR  */
@@ -1965,7 +1958,7 @@ yyreduce:
                 {
 		  (yyval.exp) = (yyvsp[0].exp);
 		}
-#line 1969 "config/m68k-parse.c"
+#line 1962 "config/m68k-parse.c"
     break;
 
   case 76: /* optexprc: %empty  */
@@ -1974,7 +1967,7 @@ yyreduce:
 		  (yyval.exp).exp.X_op = O_absent;
 		  (yyval.exp).size = SIZE_UNSPEC;
 		}
-#line 1978 "config/m68k-parse.c"
+#line 1971 "config/m68k-parse.c"
     break;
 
   case 77: /* optexprc: EXPR ','  */
@@ -1982,7 +1975,7 @@ yyreduce:
                 {
 		  (yyval.exp) = (yyvsp[-1].exp);
 		}
-#line 1986 "config/m68k-parse.c"
+#line 1979 "config/m68k-parse.c"
     break;
 
   case 79: /* reglist: reglistpair '/' ireglist  */
@@ -1990,7 +1983,7 @@ yyreduce:
                 {
 		  (yyval.mask) = (yyvsp[-2].mask) | (yyvsp[0].mask);
 		}
-#line 1994 "config/m68k-parse.c"
+#line 1987 "config/m68k-parse.c"
     break;
 
   case 80: /* reglist: reglistreg '/' ireglist  */
@@ -1998,7 +1991,7 @@ yyreduce:
                 {
 		  (yyval.mask) = (1 << (yyvsp[-2].onereg)) | (yyvsp[0].mask);
 		}
-#line 2002 "config/m68k-parse.c"
+#line 1995 "config/m68k-parse.c"
     break;
 
   case 81: /* ireglist: reglistreg  */
@@ -2006,7 +1999,7 @@ yyreduce:
                 {
 		  (yyval.mask) = 1 << (yyvsp[0].onereg);
 		}
-#line 2010 "config/m68k-parse.c"
+#line 2003 "config/m68k-parse.c"
     break;
 
   case 83: /* ireglist: reglistpair '/' ireglist  */
@@ -2014,7 +2007,7 @@ yyreduce:
                 {
 		  (yyval.mask) = (yyvsp[-2].mask) | (yyvsp[0].mask);
 		}
-#line 2018 "config/m68k-parse.c"
+#line 2011 "config/m68k-parse.c"
     break;
 
   case 84: /* ireglist: reglistreg '/' ireglist  */
@@ -2022,7 +2015,7 @@ yyreduce:
                 {
 		  (yyval.mask) = (1 << (yyvsp[-2].onereg)) | (yyvsp[0].mask);
 		}
-#line 2026 "config/m68k-parse.c"
+#line 2019 "config/m68k-parse.c"
     break;
 
   case 85: /* reglistpair: reglistreg '-' reglistreg  */
@@ -2033,7 +2026,7 @@ yyreduce:
 		  else
 		    (yyval.mask) = (1 << ((yyvsp[-2].onereg) + 1)) - 1 - ((1 << (yyvsp[0].onereg)) - 1);
 		}
-#line 2037 "config/m68k-parse.c"
+#line 2030 "config/m68k-parse.c"
     break;
 
   case 86: /* reglistreg: DR  */
@@ -2041,7 +2034,7 @@ yyreduce:
                 {
 		  (yyval.onereg) = (yyvsp[0].reg) - DATA0;
 		}
-#line 2045 "config/m68k-parse.c"
+#line 2038 "config/m68k-parse.c"
     break;
 
   case 87: /* reglistreg: AR  */
@@ -2049,7 +2042,7 @@ yyreduce:
                 {
 		  (yyval.onereg) = (yyvsp[0].reg) - ADDR0 + 8;
 		}
-#line 2053 "config/m68k-parse.c"
+#line 2046 "config/m68k-parse.c"
     break;
 
   case 88: /* reglistreg: FPR  */
@@ -2057,7 +2050,7 @@ yyreduce:
                 {
 		  (yyval.onereg) = (yyvsp[0].reg) - FP0 + 16;
 		}
-#line 2061 "config/m68k-parse.c"
+#line 2054 "config/m68k-parse.c"
     break;
 
   case 89: /* reglistreg: FPCR  */
@@ -2070,11 +2063,11 @@ yyreduce:
 		  else
 		    (yyval.onereg) = 26;
 		}
-#line 2074 "config/m68k-parse.c"
+#line 2067 "config/m68k-parse.c"
     break;
 
 
-#line 2078 "config/m68k-parse.c"
+#line 2071 "config/m68k-parse.c"
 
       default: break;
     }
@@ -2156,6 +2149,7 @@ yyerrorlab:
      label yyerrorlab therefore never appears in user code.  */
   if (0)
     YYERROR;
+  ++yynerrs;
 
   /* Do not reclaim the symbols of the rule whose action triggered
      this YYERROR.  */
@@ -2216,7 +2210,7 @@ yyerrlab1:
 `-------------------------------------*/
 yyacceptlab:
   yyresult = 0;
-  goto yyreturn;
+  goto yyreturnlab;
 
 
 /*-----------------------------------.
@@ -2224,24 +2218,22 @@ yyacceptlab:
 `-----------------------------------*/
 yyabortlab:
   yyresult = 1;
-  goto yyreturn;
+  goto yyreturnlab;
 
 
-#if !defined yyoverflow
-/*-------------------------------------------------.
-| yyexhaustedlab -- memory exhaustion comes here.  |
-`-------------------------------------------------*/
+/*-----------------------------------------------------------.
+| yyexhaustedlab -- YYNOMEM (memory exhaustion) comes here.  |
+`-----------------------------------------------------------*/
 yyexhaustedlab:
   yyerror (YY_("memory exhausted"));
   yyresult = 2;
-  goto yyreturn;
-#endif
+  goto yyreturnlab;
 
 
-/*-------------------------------------------------------.
-| yyreturn -- parsing is finished, clean up and return.  |
-`-------------------------------------------------------*/
-yyreturn:
+/*----------------------------------------------------------.
+| yyreturnlab -- parsing is finished, clean up and return.  |
+`----------------------------------------------------------*/
+yyreturnlab:
   if (yychar != YYEMPTY)
     {
       /* Make sure we have latest lookahead translation.  See comments at
@@ -2353,7 +2345,7 @@ yylex (void)
   int c = 0;
   int tail = 0;
 
-  if (*str == ' ')
+  if (is_whitespace (*str))
     ++str;
 
   if (*str == '\0')
