@@ -1,5 +1,5 @@
 /* tc-mt.h -- Header file for tc-mt.c.
-   Copyright (C) 2005-2021 Free Software Foundation, Inc.
+   Copyright (C) 2005-2025 Free Software Foundation, Inc.
 
    This file is part of GAS, the GNU Assembler.
 
@@ -49,9 +49,6 @@ extern void mt_apply_fix (struct fix *, valueT *, segT);
 /* Call md_pcrel_from_section(), not md_pcrel_from().  */
 #define MD_PCREL_FROM_SECTION(FIXP, SEC) md_pcrel_from_section (FIXP, SEC)
 
-#define obj_fix_adjustable(fixP) iq2000_fix_adjustable (fixP)
-extern bfd_boolean mt_fix_adjustable (struct fix *);
-
 /* Values passed to md_apply_fix don't include the symbol value.  */
 #define MD_APPLY_SYM_VALUE(FIX) 0
 
@@ -64,5 +61,5 @@ extern void gas_cgen_md_operand (expressionS *);
 extern int mt_force_relocation (struct fix *);
 
 #define tc_fix_adjustable(fixP) mt_fix_adjustable (fixP)
-extern bfd_boolean mt_fix_adjustable (struct fix *);
+extern bool mt_fix_adjustable (struct fix *);
 
