@@ -250,9 +250,9 @@ fill_type *exp_get_fill
   (etree_type *, fill_type *, char *);
 bfd_vma exp_get_abs_int
   (etree_type *, int, char *);
-void ldexp_init (void);
+void ldexp_init (bool);
 void ldexp_finalize_syms (void);
 bool ldexp_is_final_sym_absolute (const struct bfd_link_hash_entry *);
-void ldexp_finish (void);
+void ldexp_finish (bool);
 
 #endif
