@@ -252,7 +252,7 @@ plugin_opt_plugin (const char *plugin)
   newplug->name = plugin;
   newplug->dlhandle = dlopen (plugin, RTLD_NOW);
   if (!newplug->dlhandle)
-    einfo (_("%F%P: %s: error loading plugin: %s\n"), plugin, dlerror ());
+    fatal (_("%P: %s: error loading plugin: %s\n"), plugin, dlerror ());
 
   /* Check if plugin has been loaded already.  */
   while (curplug)
@@ -315,12 +315,11 @@ plugin_opt_plugin_arg (const char *arg)
 static bfd *
 plugin_get_ir_dummy_bfd (const char *name, bfd *srctemplate)
 {
-  bfd *abfd;
-  bool bfd_plugin_target;
-
-  bfd_plugin_target = bfd_plugin_target_p (srctemplate->xvec);
-  abfd = bfd_create (concat (name, IRONLY_SUFFIX, (const char *) NULL),
-		     bfd_plugin_target ? link_info.output_bfd : srctemplate);
+  bool bfd_plugin_target = bfd_plugin_target_p (srctemplate->xvec);
+  char *filename = concat (name, IRONLY_SUFFIX, (const char *) NULL);
+  bfd *abfd = bfd_create (filename, (bfd_plugin_target
+				     ? link_info.output_bfd : srctemplate));
+  free (filename);
   if (abfd != NULL)
     {
       abfd->flags |= BFD_LINKER_CREATED | BFD_PLUGIN;
@@ -344,7 +343,7 @@ plugin_get_ir_dummy_bfd (const char *name, bfd *srctemplate)
 	}
     }
  report_error:
-  einfo (_("%F%P: could not create dummy IR bfd: %E\n"));
+  fatal (_("%P: could not create dummy IR bfd: %E\n"));
   return NULL;
 }
 
@@ -367,7 +366,8 @@ asymbol_from_plugin_symbol (bfd *abfd, asymbol *asym,
 
   asym->the_bfd = abfd;
   asym->name = (ldsym->version
-		? concat (ldsym->name, "@", ldsym->version, (const char *) NULL)
+		? stat_concat (ldsym->name, "@", ldsym->version,
+			       (const char *) NULL)
 		: ldsym->name);
   asym->value = 0;
   switch (ldsym->def)
@@ -379,11 +379,11 @@ asymbol_from_plugin_symbol (bfd *abfd, asymbol *asym,
       flags |= BSF_GLOBAL;
       if (ldsym->comdat_key)
 	{
-	  char *name = concat (".gnu.linkonce.t.", ldsym->comdat_key,
-			       (const char *) NULL);
+	  char *name = stat_concat (".gnu.linkonce.t.", ldsym->comdat_key,
+				    (const char *) NULL);
 	  section = bfd_get_section_by_name (abfd, name);
 	  if (section != NULL)
-	    free (name);
+	    stat_free (name);
 	  else
 	    {
 	      flagword sflags;
@@ -425,7 +425,7 @@ asymbol_from_plugin_symbol (bfd *abfd, asymbol *asym,
       unsigned char visibility;
 
       if (!elfsym)
-	einfo (_("%F%P: %s: non-ELF symbol in ELF BFD!\n"), asym->name);
+	fatal (_("%P: %s: non-ELF symbol in ELF BFD!\n"), asym->name);
 
       if (ldsym->def == LDPK_COMMON)
 	{
@@ -436,7 +436,7 @@ asymbol_from_plugin_symbol (bfd *abfd, asymbol *asym,
       switch (ldsym->visibility)
 	{
 	default:
-	  einfo (_("%F%P: unknown ELF symbol visibility: %d!\n"),
+	  fatal (_("%P: unknown ELF symbol visibility: %d!\n"),
 		 ldsym->visibility);
 	  return LDPS_ERR;
 
@@ -558,7 +558,7 @@ get_view (const void *handle, const void **viewp)
 
   /* FIXME: einfo should support %lld.  */
   if ((off_t) size != input->filesize)
-    einfo (_("%F%P: unsupported input file size: %s (%ld bytes)\n"),
+    fatal (_("%P: unsupported input file size: %s (%ld bytes)\n"),
 	   input->name, (long) input->filesize);
 
   /* Check the cached view buffer.  */
@@ -834,7 +834,7 @@ get_symbols (const void *handle, int nsyms, struct ld_plugin_symbol *syms,
 	  && blhe->type != bfd_link_hash_common)
 	{
 	  /* We should not have a new, indirect or warning symbol here.  */
-	  einfo (_("%F%P: %s: plugin symbol table corrupt (sym type %d)\n"),
+	  fatal (_("%P: %s: plugin symbol table corrupt (sym type %d)\n"),
 		 called_plugin->name, blhe->type);
 	}
 
@@ -986,13 +986,14 @@ message (int level, const char *format, ...)
     case LDPL_ERROR:
     default:
       {
-	char *newfmt = concat (level == LDPL_FATAL ? "%F" : "%X",
-			       _("%P: error: "), format, "\n",
+	char *newfmt = concat (_("%X%P: error: "), format, "\n",
 			       (const char *) NULL);
 	fflush (stdout);
 	vfinfo (stderr, newfmt, args, true);
 	fflush (stderr);
 	free (newfmt);
+	if (level == LDPL_FATAL)
+	  fatal ("");
       }
       break;
     }
@@ -1121,7 +1122,7 @@ plugin_load_plugins (void)
     }
 
   /* Allocate tv array and initialise constant part.  */
-  my_tv = xmalloc ((max_args + 1 + tv_header_size) * sizeof *my_tv);
+  my_tv = stat_alloc ((max_args + 1 + tv_header_size) * sizeof (*my_tv));
   set_tv_header (my_tv);
 
   /* Pass over plugins again, activating them.  */
@@ -1135,14 +1136,14 @@ plugin_load_plugins (void)
       if (!onloadfn)
 	onloadfn = (ld_plugin_onload) dlsym (curplug->dlhandle, "_onload");
       if (!onloadfn)
-	einfo (_("%F%P: %s: error loading plugin: %s\n"),
+	fatal (_("%P: %s: error loading plugin: %s\n"),
 	       curplug->name, dlerror ());
       set_tv_plugin_args (curplug, &my_tv[tv_header_size]);
       called_plugin = curplug;
       rv = (*onloadfn) (my_tv);
       called_plugin = NULL;
       if (rv != LDPS_OK)
-	einfo (_("%F%P: %s: plugin error: %d\n"), curplug->name, rv);
+	fatal (_("%P: %s: plugin error: %d\n"), curplug->name, rv);
       curplug = curplug->next;
     }
 
@@ -1206,7 +1207,7 @@ plugin_strdup (bfd *abfd, const char *str)
   strlength = strlen (str) + 1;
   copy = bfd_alloc (abfd, strlength);
   if (copy == NULL)
-    einfo (_("%F%P: plugin_strdup failed to allocate memory: %s\n"),
+    fatal (_("%P: plugin_strdup failed to allocate memory: %s\n"),
 	   bfd_get_error ());
   memcpy (copy, str, strlength);
   return copy;
@@ -1248,7 +1249,7 @@ plugin_object_p (bfd *ibfd, bool known_used)
 
   input = bfd_alloc (abfd, sizeof (*input));
   if (input == NULL)
-    einfo (_("%F%P: plugin failed to allocate memory for input: %s\n"),
+    fatal (_("%P: plugin failed to allocate memory for input: %s\n"),
 	   bfd_get_error ());
 
   if (!bfd_plugin_open_input (ibfd, &file))
@@ -1277,7 +1278,7 @@ plugin_object_p (bfd *ibfd, bool known_used)
 
   if (plugin_call_claim_file (&file, &claimed, &claim_file_handler_v2,
 			      known_used))
-    einfo (_("%F%P: %s: plugin reported error claiming file\n"),
+    fatal (_("%P: %s: plugin reported error claiming file\n"),
 	   plugin_error_plugin ());
 
   if (input->fd != -1
@@ -1326,8 +1327,13 @@ plugin_object_p (bfd *ibfd, bool known_used)
 #endif
 
       /* If plugin didn't claim the file, we don't need the dummy bfd.
-	 Can't avoid speculatively creating it, alas.  */
-      ibfd->plugin_format = bfd_plugin_no;
+	 Can't avoid speculatively creating it, alas.  NB: Set input
+	 plugin_format to bfd_plugin_no only if known_used is set or
+	 the LDPT_REGISTER_CLAIM_FILE_HOOK_V2 linker plugin hook is
+	 unused since the V2 linker plugin hook doesn't claim the
+	 offload IR if known_used is unset.  */
+      if (known_used || !claim_file_handler_v2)
+	ibfd->plugin_format = bfd_plugin_no;
       bfd_close_all_done (abfd);
       return NULL;
     }
@@ -1341,6 +1347,9 @@ plugin_maybe_claim (lang_input_statement_type *entry)
     {
       bfd *abfd = entry->the_bfd->plugin_dummy_bfd;
 
+      /* Check object only section.  */
+      cmdline_check_object_only_section (entry->the_bfd, true);
+
       /* Discard the real file's BFD and substitute the dummy one.  */
 
       /* We can't call bfd_close on archives.  BFD archive handling
